"""
Support for setting up and defining a taxonomy
"""
from .taxonomy import Taxonomy, Taxon, RemoteTaxonomy
